@@ -29,9 +29,9 @@ class Inventory(ServiceWorkersImpl):
             response_code: int
             response_body: Any
 
-        def execute(self, task: Task, task_result: TaskResult) -> TaskResult:
+        def execute(self, task: Task) -> TaskResult:
             response = inventory.get_device_status(**task.input_data)
-            return response_handler(response, task_result)
+            return response_handler(response)
 
     ###############################################################################
 
@@ -40,8 +40,8 @@ class Inventory(ServiceWorkersImpl):
             name = "INVENTORY_install_device_by_id"
             description = "Install device by device ID"
             labels = ["BASIC", "INVENTORY"]
-            timeoutSeconds = 3600
-            responseTimeoutSeconds = 3600
+            timeout_seconds = 3600
+            response_timeout_seconds = 3600
 
         class WorkerInput(TaskInput):
             device_id: Optional[str]
@@ -51,9 +51,9 @@ class Inventory(ServiceWorkersImpl):
             response_code: int
             response_body: Any
 
-        def execute(self, task: Task, task_result: TaskResult) -> TaskResult:
+        def execute(self, task: Task) -> TaskResult:
             response = inventory.install_device_by_id(**task.input_data)
-            return response_handler(response, task_result)
+            return response_handler(response)
 
     ###############################################################################
 
@@ -62,8 +62,8 @@ class Inventory(ServiceWorkersImpl):
             name = "INVENTORY_uninstall_device_by_id"
             description = "Uninstall device by device ID"
             labels = ["BASIC", "INVENTORY"]
-            timeoutSeconds = 3600
-            responseTimeoutSeconds = 3600
+            timeout_seconds = 3600
+            response_timeout_seconds = 3600
 
         class WorkerInput(TaskInput):
             device_id: Optional[str]
@@ -73,9 +73,9 @@ class Inventory(ServiceWorkersImpl):
             response_code: int
             response_body: Any
 
-        def execute(self, task: Task, task_result: TaskResult) -> TaskResult:
+        def execute(self, task: Task) -> TaskResult:
             response = inventory.uninstall_device_by_id(**task.input_data)
-            return response_handler(response, task_result)
+            return response_handler(response)
 
     ###############################################################################
     class InventoryInstallDeviceByName(WorkerImpl):
@@ -83,8 +83,8 @@ class Inventory(ServiceWorkersImpl):
             name = "INVENTORY_install_device_by_name"
             description = "Install device by device name"
             labels = ["BASIC", "INVENTORY"]
-            timeoutSeconds = 3600
-            responseTimeoutSeconds = 3600
+            timeout_seconds = 3600
+            response_timeout_seconds = 3600
 
         class WorkerInput(TaskInput):
             device_name: str
@@ -94,9 +94,9 @@ class Inventory(ServiceWorkersImpl):
             response_code: int
             response_body: Any
 
-        def execute(self, task: Task, task_result: TaskResult) -> TaskResult:
+        def execute(self, task: Task) -> TaskResult:
             response = inventory.install_device_by_name(**task.input_data)
-            return response_handler(response, task_result)
+            return response_handler(response)
 
     ###############################################################################
 
@@ -105,8 +105,8 @@ class Inventory(ServiceWorkersImpl):
             name = "INVENTORY_uninstall_device_by_name"
             description = "Uninstall device by device name"
             labels = ["BASIC", "INVENTORY"]
-            timeoutSeconds = 3600
-            responseTimeoutSeconds = 3600
+            timeout_seconds = 3600
+            response_timeout_seconds = 3600
 
         class WorkerInput(TaskInput):
             device_name: Optional[str]
@@ -116,9 +116,9 @@ class Inventory(ServiceWorkersImpl):
             response_code: int
             response_body: Any
 
-        def execute(self, task: Task, task_result: TaskResult) -> TaskResult:
+        def execute(self, task: Task) -> TaskResult:
             response = inventory.uninstall_device_by_name(**task.input_data)
-            return response_handler(response, task_result)
+            return response_handler(response)
 
     ###############################################################################
 
@@ -127,8 +127,8 @@ class Inventory(ServiceWorkersImpl):
             name = "INVENTORY_get_labels"
             description = "Get device labels"
             labels = ["BASICS", "MAIN", "INVENTORY"]
-            timeoutSeconds = 3600
-            responseTimeoutSeconds = 3600
+            timeout_seconds = 3600
+            response_timeout_seconds = 3600
 
         class WorkerInput(TaskInput):
             ...
@@ -138,9 +138,9 @@ class Inventory(ServiceWorkersImpl):
             response_code: int
             response_body: Any
 
-        def execute(self, task: Task, task_result: TaskResult) -> TaskResult:
+        def execute(self, task: Task) -> TaskResult:
             response = inventory.get_labels()
-            return response_handler(response, task_result)
+            return response_handler(response)
 
     ###############################################################################
 
@@ -149,8 +149,8 @@ class Inventory(ServiceWorkersImpl):
             name = "INVENTORY_create_label"
             description = "Create device labels"
             labels = ["BASICS", "MAIN", "INVENTORY"]
-            timeoutSeconds = 3600
-            responseTimeoutSeconds = 3600
+            timeout_seconds = 3600
+            response_timeout_seconds = 3600
 
         class WorkerInput(TaskInput):
             label: str
@@ -160,9 +160,9 @@ class Inventory(ServiceWorkersImpl):
             response_code: int
             response_body: Any
 
-        def execute(self, task: Task, task_result: TaskResult) -> TaskResult:
+        def execute(self, task: Task) -> TaskResult:
             response = inventory.create_label(**task.input_data)
-            return response_handler(response, task_result)
+            return response_handler(response)
 
     ###############################################################################
 
@@ -171,8 +171,8 @@ class Inventory(ServiceWorkersImpl):
             name = "INVENTORY_add_device"
             description = "Add device to inventory database"
             labels = ["BASICS", "MAIN", "INVENTORY"]
-            timeoutSeconds = 3600
-            responseTimeoutSeconds = 3600
+            timeout_seconds = 3600
+            response_timeout_seconds = 3600
 
         class WorkerInput(TaskInput):
             device_name: str
@@ -189,9 +189,9 @@ class Inventory(ServiceWorkersImpl):
             response_code: int
             response_body: Any
 
-        def execute(self, task: Task, task_result: TaskResult) -> TaskResult:
+        def execute(self, task: Task) -> TaskResult:
             response = inventory.add_device(**task.input_data)
-            return response_handler(response, task_result)
+            return response_handler(response)
 
     ###############################################################################
     class InventoryGetPagesCursors(WorkerImpl):
@@ -199,8 +199,8 @@ class Inventory(ServiceWorkersImpl):
             name = "INVENTORY_get_pages_cursors"
             description = "Get a list of pages cursors from device inventory"
             labels = ["BASIC", "INVENTORY"]
-            retry_timeout = 3600
-            responseTimeoutSeconds = 3600
+            timeout_seconds = 3600
+            response_timeout_seconds = 3600
 
         class WorkerInput(TaskInput):
             labels: Optional[str]
@@ -213,9 +213,9 @@ class Inventory(ServiceWorkersImpl):
             page_size: str
             page_ids: str
 
-        def execute(self, task: Task, task_result: TaskResult) -> TaskResult:
+        def execute(self, task: Task) -> TaskResult:
             response = inventory.get_device_pages_cursors(**task.input_data)
-            return response_handler(response, task_result)
+            return response_handler(response)
 
     ###############################################################################
 
@@ -236,9 +236,9 @@ class Inventory(ServiceWorkersImpl):
             response_code: int
             response_body: Any
 
-        def execute(self, task: Task, task_result: TaskResult) -> TaskResult:
+        def execute(self, task: Task) -> TaskResult:
             response = inventory.all_devices_fork_tasks(**task.input_data)
-            return response_handler(response, task_result)
+            return response_handler(response)
 
     ###############################################################################
     class InventoryGetPagesCursorsForkTasks(WorkerImpl):
@@ -246,8 +246,8 @@ class Inventory(ServiceWorkersImpl):
             name = "INVENTORY_get_pages_cursors_fork_tasks"
             description = "Get all pages cursors as dynamic fork tasks"
             labels = ["BASIC", "INVENTORY"]
-            timeoutSeconds = 3600
-            responseTimeoutSeconds = 3600
+            timeout_seconds = 3600
+            response_timeout_seconds = 3600
 
         class WorkerInput(TaskInput):
             task: str
@@ -259,9 +259,9 @@ class Inventory(ServiceWorkersImpl):
             response_code: int
             response_body: Any
 
-        def execute(self, task: Task, task_result: TaskResult) -> TaskResult:
+        def execute(self, task: Task) -> TaskResult:
             response = inventory.page_device_dynamic_fork_tasks(**task.input_data)
-            return response_handler(response, task_result)
+            return response_handler(response)
 
     ###############################################################################
 
@@ -270,8 +270,8 @@ class Inventory(ServiceWorkersImpl):
             name = "INVENTORY_install_in_batch"
             description = "Install devices in batch started from page cursor"
             labels = ["BASIC", "INVENTORY"]
-            timeoutSeconds = 3600
-            responseTimeoutSeconds = 3600
+            timeout_seconds = 3600
+            response_timeout_seconds = 3600
 
         class WorkerInput(TaskInput):
             page_size: str
@@ -283,9 +283,9 @@ class Inventory(ServiceWorkersImpl):
             dynamic_tasks_i: str
             dynamic_tasks: str
 
-        def execute(self, task: Task, task_result: TaskResult) -> TaskResult:
+        def execute(self, task: Task) -> TaskResult:
             response = inventory.install_in_batch(**task.input_data)
-            return response_handler(response, task_result)
+            return response_handler(response)
 
     ###############################################################################
 
@@ -294,8 +294,8 @@ class Inventory(ServiceWorkersImpl):
             name = "INVENTORY_uninstall_in_batch"
             description = "Uninstall devices in batch started from page cursor"
             labels = ["BASIC", "INVENTORY"]
-            timeoutSeconds = 3600
-            responseTimeoutSeconds = 3600
+            timeout_seconds = 3600
+            response_timeout_seconds = 3600
 
         class WorkerInput(TaskInput):
             page_size: int
@@ -307,19 +307,21 @@ class Inventory(ServiceWorkersImpl):
             dynamic_tasks_i: str
             dynamic_tasks: str
 
-        def execute(self, task: Task, task_result: TaskResult) -> TaskResult:
+        def execute(self, task: Task) -> TaskResult:
             response = inventory.uninstall_in_batch(**task.input_data)
-            return response_handler(response, task_result)
+            return response_handler(response)
 
 
-def response_handler(response: InventoryOutput, task_result: TaskResult) -> TaskResult:
+def response_handler(response: InventoryOutput) -> TaskResult:
     match response.status:
         case "data":
+            task_result = TaskResult(status=TaskResultStatus.COMPLETED)
             task_result.status = TaskResultStatus.COMPLETED
             task_result.add_output_data("response_code", response.code)
             task_result.add_output_data("response_body", response.data)
             return task_result
         case _:
+            task_result = TaskResult(status=TaskResultStatus.FAILED)
             task_result.status = TaskResultStatus.FAILED
             task_result.logs = str(response)
             task_result.add_output_data("response_code", response.code)
